package com.ruoyi.inventory.mapper;

import java.util.List;
import com.ruoyi.inventory.domain.TbAssetInventory;
import com.ruoyi.inventory.domain.TbInventoryDetail;
import com.ruoyi.inventory.domain.dto.AssetInvOrderDto;
import com.ruoyi.inventory.domain.dto.DepAssetDetailDto;
import com.ruoyi.inventory.domain.dto.DepAssetLossDto;
import com.ruoyi.inventory.domain.dto.TbAssetInventoryDTO;
import org.apache.ibatis.annotations.Param;

/**
 * 资产盘点记录Mapper接口
 *
 * @author ydl
 * @date 2023-06-01
 */
public interface TbAssetInventoryMapper
{
    /**
     * 查询资产盘点记录
     *
     * @param id 资产盘点记录主键
     * @return 资产盘点记录
     */
    public TbAssetInventory selectTbAssetInventoryById(Long id);

    public TbAssetInventory selectTbAssetInventoryByNumber(String orderNumber);

    public List<String> selectOrderNumberByIds(@Param("ids") List<Long> ids);

    /**
     * 查询资产盘点记录列表
     *
     * @param tbAssetInventory 资产盘点记录
     * @return 资产盘点记录集合
     */
    public List<TbAssetInventory> selectTbAssetInventoryList(TbAssetInventory tbAssetInventory);

    /**
     * 查询全单位盘点资产对比分析列表
     * @return
     */
    public List<TbAssetInventory> selectTbAssetInventoryListBy(String deptId);
    /**
     * 新增资产盘点记录
     *
     * @param tbAssetInventory 资产盘点记录
     * @return 结果
     */
    public int insertTbAssetInventory(TbAssetInventory tbAssetInventory);

    /**
     * 修改资产盘点记录
     *
     * @param tbAssetInventory 资产盘点记录
     * @return 结果
     */
    public int updateTbAssetInventory(TbAssetInventory tbAssetInventory);

    /**
     * 删除资产盘点记录
     *
     * @param id 资产盘点记录主键
     * @return 结果
     */
    public int deleteTbAssetInventoryById(Long id);

    /**
     * 批量删除资产盘点记录
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTbAssetInventoryByIds(Long[] ids);

    /**
     * 查询资产盘点记录列表
     *
     * @param dto 资产盘点记录
     * @return 资产盘点记录集合
     */
    public List<TbAssetInventoryDTO> selectTbAssetInventoryDTOList(TbAssetInventoryDTO dto);

    List<DepAssetDetailDto> getDepAssetByOrderNumber(String orderNumber);

    List<AssetInvOrderDto> getOrderNumberByDepId(@Param("depId") String depId);

    List<String> getChildDeptId(String deptId);


}
